package xn.update;

import android.annotation.SuppressLint;
import android.content.Intent;
import android.os.AsyncTask;
import android.os.Bundle;
import android.provider.Settings;
import android.text.TextUtils;
import android.util.Log;
import android.view.View;
import android.widget.CompoundButton;

import androidx.activity.EdgeToEdge;
import androidx.annotation.Nullable;
import androidx.appcompat.app.AppCompatActivity;
import androidx.core.graphics.Insets;
import androidx.core.view.ViewCompat;
import androidx.core.view.WindowInsetsCompat;

import com.blankj.utilcode.util.ActivityUtils;
import com.blankj.utilcode.util.AppUtils;
import com.blankj.utilcode.util.GsonUtils;
import com.blankj.utilcode.util.LogUtils;
import com.blankj.utilcode.util.SPUtils;
import com.blankj.utilcode.util.ThreadUtils;
import com.blankj.utilcode.util.TimeUtils;
import com.blankj.utilcode.util.ToastUtils;
import com.hikvision.dmb.EthernetConfig;
import com.hikvision.dmb.LauncherInfo;
import com.hikvision.dmb.MemoryInfo;
import com.hikvision.dmb.TimeSwitchConfig;
import com.hikvision.dmb.display.InfoDisplayApi;
import com.hikvision.dmb.network.InfoNetworkApi;
import com.hikvision.dmb.system.InfoSystemApi;
import com.hikvision.dmb.time.InfoTimeApi;
import com.hikvision.dmb.util.InfoUtilApi;
import com.lxj.xpopupext.popup.TimePickerPopup;

import xn.update.databinding.ActivitySettingBinding;

@SuppressLint("SetTextI18n")
public class SettingActivity extends AppCompatActivity {
    private ActivitySettingBinding binding;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        binding = ActivitySettingBinding.inflate(getLayoutInflater());
        setContentView(binding.getRoot());
    }

    @Override
    protected void onPostCreate(@Nullable Bundle savedInstanceState) {
        super.onPostCreate(savedInstanceState);
        AsyncTask.execute(() -> runOnUiThread(() -> {
            // 状态栏
            binding.statusSwitch.setChecked(InfoDisplayApi.getStatusBarEnable());
            binding.statusSwitch.setOnCheckedChangeListener((buttonView, isChecked) -> InfoDisplayApi.setStatusBarEnable(isChecked));
            // 导航栏
            binding.navSwitch.setChecked(InfoDisplayApi.getNavigationBarEnable());
            binding.navSwitch.setOnCheckedChangeListener((buttonView, isChecked) -> InfoDisplayApi.setNavigationBarEnable(isChecked));
            // app版本
            binding.varBT.setText("版本:" + AppUtils.getAppVersionName());
            String sn = InfoSystemApi.getSerialNumber();
            // 设备sn
            binding.snBT.setText("SN:" + (TextUtils.isEmpty(sn) ? "NULL" : sn));
            // 网络ip
            EthernetConfig ethernetConfig = InfoNetworkApi.getEthernetConfig();
            String ip = ethernetConfig.getIpAddress();
            binding.ipBT.setText("Ip:" + (TextUtils.isEmpty(ip) ? "NULL" : ip));
            // 启动文件管理
            binding.fileBrowserBT.setOnClickListener(v -> Tool.INSTANCE.openFileBrowser());
            // 重启设备
            binding.rebootBT.setOnClickListener(v -> {
                        InfoSystemApi.reboot();
                        SPUtils.getInstance().put("isDebug", false);
                    }
            );
            // 系统设置
            binding.settingBT.setOnClickListener(v -> {
                Tool.INSTANCE.openSetting();
            });
            // 超级权限
            if (SPUtils.getInstance().getBoolean("isRoot", false)) {
                binding.rootCV.setVisibility(View.VISIBLE);
            }
            // 温度
            binding.temperatureBT.setText("温度:" + InfoSystemApi.getTemperature());
            // CPU
            binding.cpuBT.setText(InfoSystemApi.getCpuUsageRate());
            // 内存
            MemoryInfo memoryInfo = InfoSystemApi.getMemoryUsage();
            binding.memoryBT.setText("内存:" + memoryInfo.describe);
            // 保存
            binding.save.setOnClickListener(v -> save());
        }));
    }

    private void save() {
        finish();
        SPUtils.getInstance().put("isDebug", false);
        Tool.INSTANCE.openApp("com.dlc.xn.eboard");
    }
}