package xn.update;

import android.net.Uri;
import android.util.Log;

import com.blankj.utilcode.util.ActivityUtils;
import com.blankj.utilcode.util.AppUtils;
import com.blankj.utilcode.util.LogUtils;
import com.blankj.utilcode.util.SPUtils;
import com.blankj.utilcode.util.ShellUtils;
import com.hikvision.dmb.system.InfoSystemApi;

import okhttp3.HttpUrl;
import xn.update.service.TaskService;

public enum Tool {
    INSTANCE;

    public void reStartApp() {
        exitApp();
        InfoSystemApi.execCommand("monkey -p " + AppUtils.getAppPackageName() + " -c android.intent.category.LAUNCHER 1");
    }

    public void openFileBrowser() {
        openApp("display.interactive.filebrowser");
    }

    public void exitApp() {
        InfoSystemApi.execCommand("am force-stop " + AppUtils.getAppPackageName());
    }

    public void openSetting() {
        openApp("display.interactive.hsetting");
    }

    public void openApp(String packageName) {
        InfoSystemApi.execCommand("monkey -p " + packageName + " -c android.intent.category.LAUNCHER 1");
    }

    public ShellUtils.CommandResult stopApp(String packageName) {
        return ShellUtils.execCmd("am force-stop " + packageName, true);
    }

    public void startMasterApp() {
        openApp(SPUtils.getInstance().getString("masterApp", "com.dlc.xn.eboard"));
    }

    public void startTaskService() {
        cmd("am startservice -n xn.update/xn.update.service.TaskService");
    }

    public int cmd(String cmd) {
        int result = InfoSystemApi.execCommand(cmd);
        LogUtils.d(cmd, result);
        return result;
    }

    public String getSerialNumber() {
        return "EBOARD_" + InfoSystemApi.getSerialNumber();
    }

    public HttpUrl getBaseUrl() {
        if (AppUtils.isAppDebug()) {
            return HttpUrl.get("http://192.168.1.8/api/");
        } else {
            return HttpUrl.get("http://172.16.0.65/api/");
        }
    }

    public String checkUrl(String url) {
        try {
            String uriStr = url;
            if (!url.matches("https?://.*") && !url.matches("http?://.*")) {
                uriStr = Uri.parse(getBaseUrl() + url).toString();
            }
            return uriStr;
        } catch (Exception e) {
            LogUtils.e(Log.getStackTraceString(e));
            return url;
        }
    }
}
