package xn.update.http;

import android.text.TextUtils;
import android.util.Log;

import androidx.annotation.NonNull;

import com.blankj.utilcode.util.GsonUtils;
import com.blankj.utilcode.util.LogUtils;
import com.blankj.utilcode.util.SPUtils;

import java.io.IOException;
import java.nio.charset.StandardCharsets;

import okhttp3.Interceptor;
import okhttp3.Request;
import okhttp3.Response;
import okhttp3.ResponseBody;
import okio.Buffer;
import okio.BufferedSource;
import xn.update.Tool;

public class LogInterceptor implements Interceptor {
    @NonNull
    @Override
    public Response intercept(@NonNull Chain chain) throws IOException {
        try {
            Request oldRequest = chain.request();
            Request.Builder newRequestBuilder = oldRequest.newBuilder();
            String terminalAuth = SPUtils.getInstance().getString("TerminalAuth", "");
            if (null != terminalAuth && !TextUtils.isEmpty(terminalAuth)) {
                newRequestBuilder.header("TerminalAuth", "Bearer " + terminalAuth);
            }
            newRequestBuilder.header("SN", Tool.INSTANCE.getSerialNumber());
            newRequestBuilder.header("IP", SPUtils.getInstance().getString("IP", "127.0.0.1"));

            Request newRequest = newRequestBuilder.build();
            // 记录请求报文
            String requestLog = "--> " + newRequest.method() + " " + newRequest.url() + "\n"
                    + newRequest.headers() + "\n"
                    + (newRequest.body() != null ? GsonUtils.toJson(newRequest.body()) : ""); // 请求体可能为空
            LogUtils.d(requestLog);

            Response response = chain.proceed(newRequest);
            ResponseBody responseBody = response.body();
            BufferedSource source = responseBody.source();
            source.request(Long.MAX_VALUE);
            Buffer buffer = source.getBuffer();
            String responseBodyString = buffer.clone().readString(StandardCharsets.UTF_8);
            // 记录响应报文
            String responseLog = "<-- " + response.code() + " " + response.message() + " " + response.request().url() + "\n"
                    + response.headers() + "\n"
                    + (response.body() != null ? responseBodyString : ""); // 响应体可能为空
            LogUtils.d(responseLog);
            return response.newBuilder().body(ResponseBody.create(responseBody.contentType(), responseBodyString)).build();
        } catch (Exception e) {
            LogUtils.e(Log.getStackTraceString(e));
        }
        return chain.proceed(chain.request());
    }
}
