package xn.update.http.bean;

import android.text.TextUtils;
import android.util.Log;

import androidx.annotation.NonNull;

import com.blankj.utilcode.util.LogUtils;
import com.blankj.utilcode.util.SPUtils;

import java.io.IOException;
import java.nio.charset.Charset;
import java.nio.charset.StandardCharsets;

import okhttp3.Interceptor;
import okhttp3.Request;
import okhttp3.RequestBody;
import okhttp3.Response;
import okhttp3.ResponseBody;
import okio.Buffer;
import okio.BufferedSource;
import xn.update.Tool;

public class AllLogInterceptor implements Interceptor {
    @NonNull
    @Override
    public Response intercept(@NonNull Chain chain) throws IOException {
        try {
            Request request = chain.request();
            Request.Builder newRequestBuilder = request.newBuilder();
            String terminalAuth = SPUtils.getInstance().getString("TerminalAuth", "");
            if (null != terminalAuth && !TextUtils.isEmpty(terminalAuth)) {
                newRequestBuilder.header("TerminalAuth", "Bearer " + terminalAuth);
            }
            newRequestBuilder.header("SN", Tool.INSTANCE.getSerialNumber());
            newRequestBuilder.header("IP", SPUtils.getInstance().getString("IP", "127.0.0.1"));
            request = newRequestBuilder.build();
            long t1 = System.nanoTime();
            // 记录请求信息
            StringBuilder requestLog = new StringBuilder();
            requestLog.append("--> ").append(request.method()).append(" ").append(request.url()).append("\n");
            requestLog.append(request.headers()).append("\n");
            // 记录请求体
            RequestBody requestBody = request.body();
            if (requestBody != null) {
                Buffer buffer = new Buffer();
                requestBody.writeTo(buffer);
                Charset charset = requestBody.contentType() != null ? requestBody.contentType().charset(StandardCharsets.UTF_8) : StandardCharsets.UTF_8;
                requestLog.append(buffer.readString(charset)).append("\n");
            }
            // 打印请求信息
            LogUtils.d(requestLog);
            // 执行请求
            Response response = chain.proceed(request);
            long t2 = System.nanoTime();
            // 记录响应信息
            StringBuilder responseLog = new StringBuilder();
            responseLog.append("<-- ").append(response.code()).append(" ").append(response.message()).append(" ").append(response.request().url()).append(" (").append((t2 - t1) / 1e6d).append("ms)\n\n");
//            responseLog.append(response.headers()).append("\n");
            // 记录响应体
            ResponseBody responseBody = response.body();
            if (responseBody != null) {
                BufferedSource source = responseBody.source();
                source.request(Long.MAX_VALUE); // Buffer the entire body.
                Buffer buffer = source.getBuffer();
                Charset charset = responseBody.contentType() != null ? responseBody.contentType().charset(StandardCharsets.UTF_8) : StandardCharsets.UTF_8;
                responseLog.append(buffer.clone().readString(charset)).append("\n"); // 使用 clone() 避免消耗响应体
                response = response.newBuilder()
                        .body(ResponseBody.create(responseBody.contentType(), buffer.size(), buffer))
                        .build();
            }
            // 打印响应信息
            LogUtils.d(responseLog);
            return response;
        } catch (Exception e) {
            LogUtils.e(Log.getStackTraceString(e));
        }
        return chain.proceed(chain.request());
    }
}
